import serial
import gtk
import glib

import widgets

ACC_PORT = 'com4:'

class ADXL (object):

	def __init__(self):
		self.device = serial.Serial(ACC_PORT, 57600, timeout=0.5)

	def read_last_line(self):
		line = ''
		while self.device.inWaiting() > 0:
			line = self.device.readline()

		return line

	def parse_args(self, line):
		try:
			data = map(float, line[5:].strip().split(','))
		except ValueError:
			return 0, 0, 0, 0, 0
		return data

	def read(self):
		line = self.read_last_line()
		while line[:5] != '#ACC=':
			line = self.read_last_line()
		data = self.parse_args(line)
		if len(data) == 5:
			return data
		return 0, 0, 0, 0, 0


class App (object):
	
	def __init__(self):
		self.window = gtk.Window()
		self.gforce = widgets.GForce()
		self.horizon = widgets.Horizon()
		self.level = widgets.Level()

		self.hbox = gtk.HBox()
		self.hbox.add(self.gforce)
		self.hbox.add(self.horizon)

		self.vbox = gtk.VBox()
		self.vbox.add(self.hbox)
		self.vbox.add(self.level)

		self.window.add(self.vbox)
		self.window.set_title('Accelerometer ADXL345')
		self.window.show_all()
		self.window.connect('destroy', self.on_destroy)

		self.device = ADXL()
		self.timer = glib.timeout_add(33, self.on_timer)
		gtk.main()
	
	def on_timer(self):
		x, y, z, roll, pitch = self.device.read()
		self.horizon.set_horizon(pitch, roll)
		self.gforce.set_accel(x, y, z)
		self.level.set_angle(roll)
		return True

	def on_destroy(self, widget, data=None):
		glib.source_remove(self.timer)
		gtk.main_quit()


if __name__ == '__main__':
	App()