#include <Wire.h>

#define ADXL_ADDR 0x53

void twiSetRegister(int address, byte reg, byte data)
{
  Wire.beginTransmission(address);
  Wire.write(reg);
  Wire.write(data);
  Wire.endTransmission();
  delay(5);
}

byte twiGetRegisters(int address, byte reg, byte *buffer, byte length)
{
  byte count = 0;
  
  Wire.beginTransmission(address);
  Wire.write(reg);
  Wire.endTransmission();
  
  Wire.beginTransmission(address);
  Wire.requestFrom(address, (int) length);
  while (Wire.available())
  {
    buffer[count] = Wire.read();
    count++;
  }
  Wire.endTransmission();
  
  return count;
}

void setup()
{
  Serial.begin(57600);
  Wire.begin();
  twiSetRegister(ADXL_ADDR, 0x2d, 0x08);
  twiSetRegister(ADXL_ADDR, 0x31, 0x08);
  twiSetRegister(ADXL_ADDR, 0x2c, 0x09);

  // kalibracja
  twiSetRegister(ADXL_ADDR, 0x1e, (char) 0);
  twiSetRegister(ADXL_ADDR, 0x1f, (char) 0);
  twiSetRegister(ADXL_ADDR, 0x20, (char) 0);
}

void loop()
{
  byte buffer[6];
  byte readed = twiGetRegisters(ADXL_ADDR, 0x32, buffer, 6);
  if (readed != 6)
  {
    Serial.println(F("ERROR"));
  }
  else
  {
    int resultX = word(buffer[1], buffer[0]);
    int resultY = word(buffer[3], buffer[2]);
    int resultZ = word(buffer[5], buffer[4]);
    
    float gX = resultX * 0.004;
    float gY = resultY * 0.004;
    float gZ = resultZ * 0.004;
    
    float roll = atan2(gX, gZ) * 180 / PI;
    float pitch = atan2(gY, gZ) * 180 / PI;
    
    Serial.print("#ACC=");
    Serial.print(gX);
    Serial.print(",");
    Serial.print(gY);
    Serial.print(",");
    Serial.print(gZ);
    Serial.print(",");
    Serial.print(roll);
    Serial.print(",");
    Serial.println(pitch);
  }
  delay(20);
}

